@@ -16,6 +16,7 @@ NULL
 #' @param month integer vectors containing the considered months. Default is \code{1:12} (all the year). 
 #' @param melting.df logical value. If it \code{TRUE} the output is melted into a data frame. Default is \code{FALSE}.
 #' @param from.start logical value. If is \code{TRUE} the spell is referenced to its first day, if it is \code{FALSE} (default) the spell is referenced to its last date.
+#' @param only.inner logical value. It is used in case \code{extract} is not \code{NULL}, if the value is \code{TRUE}, it extracts dry/wet spells completely inside the selected \code{month} period. Default is \code{FALSE}. 
 #' 
 #' @export
 #'
@@ -61,7 +62,10 @@ NULL
 #' origin <- paste(year_min,1,1,sep="-")
 #' dw_spell <- dw.spell(prec_mes,origin=origin)
 #' dw_spell_dry <- dw.spell(prec_mes,origin=origin,extract="dry")
-#' dw_spell_dry_start <- dw.spell(prec_mes,origin=origin,extract="dry",from.start=TRUE) ## dry spell 
+#' dw_spell_dry_start <- dw.spell(prec_mes,origin=origin,extract="dry",
+#' 	month=5:8,from.start=TRUE) ## dry spell 
+#' 	dw_spell_dry_start_2 <- dw.spell(prec_mes,origin=origin,extract="dry",
+#' month=5:8,from.start=TRUE,only.inner=TRUE) ## dry spell 
 #' ## is referenced to the first day instead of the latest one as default. 
 #' 
 #' hist(dw_spell_dry[[1]]$spell_length)
@@ -72,7 +76,7 @@ NULL
 
 
 
-dw.spell <- function(data,valmin=0.5,origin="1961-1-1",extract=NULL,month=1:12,melting.df=FALSE,from.start=FALSE) {
+dw.spell <- function(data,valmin=0.5,origin="1961-1-1",extract=NULL,month=1:12,melting.df=FALSE,from.start=FALSE,only.inner=FALSE) {
 	
 	
 	out <- list()
@@ -122,16 +126,17 @@ dw.spell <- function(data,valmin=0.5,origin="1961-1-1",extract=NULL,month=1:12,m
 		
 		temp$spell_length <- spell_length
 		temp$spell_state <- spell_state
-		
+		temp$end_date <- as.Date(paste(temp$year,temp$month,temp$day,sep="-"))
+		temp$start_date <- temp$end_date-temp$spell_length+1
 		
 		### FROM START ## mod EC 20191016
-		if (from.start==TRUE) {
+		if (from.start==TRUE) {  ## MOD EC 20201007
 			
-		 end_date <- as.Date(paste(temp$year,temp$month,temp$day,sep="-"))
-		 start_date <- end_date-temp$spell_length+1
-		 temp$day <- as.numeric(as.character(start_date,format="%d"))
-		 temp$month <- as.numeric(as.character(start_date,format="%m"))
-		 temp$year <- as.numeric(as.character(start_date,format="%Y"))
+		 ##temp$end_date <- as.Date(paste(temp$year,temp$month,temp$day,sep="-"))
+		 ##temp$start_date <- temp$end_date-temp$spell_length+1
+		 temp$day <- as.numeric(as.character(temp$start_date,format="%d"))
+		 temp$month <- as.numeric(as.character(temp$start_date,format="%m"))
+		 temp$year <- as.numeric(as.character(temp$start_date,format="%Y"))
 		 
 		}		
 		out[[c]] <- temp 
@@ -141,11 +146,16 @@ dw.spell <- function(data,valmin=0.5,origin="1961-1-1",extract=NULL,month=1:12,m
 	names(out) <- names(as.data.frame(data[,ignore.date]))
 	
 	if (!is.null(extract)) {
-		
-	
-		
 		out <- lapply(X=out,FUN=function(x,extract) {x[which(x$spell_state %in% extract),]},extract=extract)
-		out <- lapply(X=out,FUN=function(x,month) {x[which(x$month %in% month),]},month=month)
+		if (only.inner==TRUE) {
+			
+			out <- lapply(X=out,FUN=function(x,month) {x[which(lubridate::month(x$start_date) %in% month),]},month=month)
+			out <- lapply(X=out,FUN=function(x,month) {x[which(lubridate::month(x$end_date) %in% month),]},month=month)
+			
+		} else {
+			
+			out <- lapply(X=out,FUN=function(x,month) {x[which(x$month %in% month),]},month=month)
+		}
 	}
 	
 	## FARE UN OPZIONE PER IL MELTING ..... 
